pub trait SchemaEvents {
// Provided methods
fn schema_events() -> Vec<Event> { ... }
fn custom_types() -> Vec<Option<CustomType>> { ... }
}Expand description
Trait representing schema events.
Provided Methods
Sourcefn schema_events() -> Vec<Event>
fn schema_events() -> Vec<Event>
Returns a vector of Events.
Sourcefn custom_types() -> Vec<Option<CustomType>>
fn custom_types() -> Vec<Option<CustomType>>
Returns a vector of CustomTypes.
This method is used to define custom types that are used in the events. An event itself is a CustomType and can have a custom type as its payload.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".